@@ -55,7 +55,6 @@ from enhancedlabelme.widgets import ZoomWidget
 LABEL_COLORMAP = imgviz.label_colormap(value=200)
 os.environ['QT_API'] = 'pyqt5'
 
-
 class PenStyleWindow(QtWidgets.QDialog):
     def __init__(self, parent=None):
         super(PenStyleWindow, self).__init__(parent)
@@ -507,7 +506,7 @@ class MainWindow(QtWidgets.QMainWindow):
         hideOthers = action(self.tr('&Immersive mode'),
                             self.immersiveMode,
                             icon='focus', tip=self.tr('Hide other polygons when creating polygon'),
-                            checkable=True, checked=self._config['hide_others'])
+                            checkable=True, checked=self._config['hide_others'], enabled=True)
         hideOthers.setChecked(self._config['hide_others'])
         
         help = action(self.tr('&About'), self.about, icon='help',
@@ -1059,17 +1058,17 @@ class MainWindow(QtWidgets.QMainWindow):
             self.canvas.cross = False
             
     def immersiveMode(self):
+        # Prevent user from toggle mode while creating polygon
         if self.canvas.immersive_ok:
             if self.actions.hideOthers.isChecked() == True:
-                self.canvas.immersive = True
+                self.actions.hideOthers.setChecked(False)
             elif self.actions.hideOthers.isChecked() == False:
-                self.canvas.immersive = False
-        else:
+                self.actions.hideOthers.setChecked(True)
+        elif not self.canvas.immersive_ok:
             if self.actions.hideOthers.isChecked() == True:
-                self.canvas.immersive = False
-            elif self.actions.hideOthers.isChecked() == False:
                 self.canvas.immersive = True
-    
+            elif self.actions.hideOthers.isChecked() == False:
+                self.canvas.immersive = False
     
     def toggleDrawingSensitive(self, drawing=True):
         """Toggle drawing sensitive.
@@ -1501,7 +1500,7 @@ class MainWindow(QtWidgets.QMainWindow):
             if self.actions.hideOthers.isChecked() == True:
                 self.canvas.keyboard_con()
                 self.canvas.immersive_first = True
-                self.canvas.immersive_ok = False
+            self.canvas.immersive_ok = False
         else:
             self.canvas.undoLastLine()
             self.canvas.shapesBackups.pop()
